@@ -10,9 +10,9 @@ def formatcc(text_to_search):
             #print(ccmatches.span(0))
             text_to_search = text_to_search[cc_end-1:]
             if cc[0] == 3:
-                pattern = re.compile(r'\d{4}')
+                pattern = re.compile(r'\d{4}\D')
             else:
-                pattern = re.compile(r'\d{3}')
+                pattern = re.compile(r'\d{3}\D')
             cvv = pattern.search(text_to_search)
             if cvv is not None:
                 cvv = cvv[0]
